Crate fuel_core_compression_service

Crate fuel_core_compression_service 

Compression Service

Modules

config
Configuration for the compression service
errors
Error types for the compression service
ports
Ports for the compression service
service
Service definition for the compression service
storage
Storage traits for the compression service
sync_state
Sync state for the compression service This module contains the SyncState enum, which represents the state of the synchronization process between storages.
temporal_registry
Temporal Registry implementations This module contains implementations of TemporalRegistry for the merkleized indexing tables

Type Aliases

Result
Result type for compression operations